((Drupal, once) => {
  Drupal.behaviors.PhoneInternational = {
    attach: () => {
      once('phoneInternational', '.phone-international-number').forEach(
        (field) => {
          const country = field.getAttribute('data-country');
          const geolocation = parseInt(field.getAttribute('data-geo'), 2);
          const exclude = field.getAttribute('data-exclude');
          const only = field.getAttribute('data-only');
          const preferred = field.getAttribute('data-preferred');
          const dialCode = parseInt(field.getAttribute('data-dial-code'), 2);
          const placeholder = field.getAttribute('data-auto-placeholder');
          const nationalNumber = field.getAttribute('data-national-number');

          const options = {
            initialCountry: geolocation === 1 ? 'auto' : country,
            nationalMode: parseInt(nationalNumber, 2) === 1,
            excludeCountries: exclude ? exclude.split('-') : [],
            onlyCountries: only ? only.split('-') : [],
            geoIpLookup: (callback) => {
              fetch(new Request('//ipinfo.io/json'))
                .then((response) => {
                  if (response.status === 200) {
                    return response.json();
                  }
                })
                .then((resp) => {
                  const countryCode =
                    resp && resp.country ? resp.country : country;
                  callback(countryCode);
                })
                .catch((error) => {
                  /* eslint-disable no-console */
                  console.error(error);
                  /* eslint-enable no-console */
                });
            },
            preferredCountries: preferred ? preferred.split('-') : [],
            autoPlaceholder: placeholder,
            separateDialCode: dialCode === 1,
            loadUtils: () =>
              import(`${drupalSettings.phone_international.path}/js/utils.js`),
          };

          Drupal.behaviors.PhoneInternational.alterPhoneLibraryOptions(
            field,
            options,
          );

          // Initialize the phone library.
          const iti = window.intlTelInput(field, options);
          // Add event lister to update the hidden input value on keyup to make
          // sure that the hidden input value is set for all ajax request
          // (the intl-tel-input library update the value on form submit only).
          field.addEventListener('keyup', () => {
            field.value = iti.getNumber();
          });
        },
      );
    },

    /**
     * Alter options before initializing intl-tel-input.
     *
     * @param {HTMLElement} field
     *   The field element.
     * @param {Object} options
     *   The list of options to init intlTelInput.
     *
     * @return {void}
     */
    // eslint-disable-next-line no-unused-vars
    alterPhoneLibraryOptions: (field, options) => {},
  };
})(Drupal, once);
