<?php

declare(strict_types=1);

namespace Drupal\phone_international\Helpers;

/**
 * Interface for phone number validation and formatting operations.
 */
interface PhoneNumberInterface {

  /**
   * Validates if a phone number is correctly formatted and legitimate.
   *
   * @param string $number
   *   The phone number to validate.
   *
   * @return bool
   *   TRUE if the number is valid, FALSE otherwise.
   */
  public function isValidNumber(string $number): bool;

  /**
   * Formats a phone number according to standardized formatting rules.
   *
   * @param string $number
   *   The phone number to format.
   *
   * @return string
   *   The formatted phone number or the original number if formatting fails.
   */
  public function formatNumber(string $number): string;

}
